"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DEFAULT_ENCODE_TOOLS_OPTIONS = exports.getDefaults = void 0;
const command_1 = require("@oclif/command");
const EncodeToolsAuto_1 = require("@znetstar/encode-tools-native/lib/EncodeToolsAuto");
const EncodeToolsNative_1 = require("@znetstar/encode-tools-native/lib/EncodeToolsNative");
const fs_1 = require("fs");
const path = require("path");
const os = require("os");
let defaults;
function getDefaults() {
    if (defaults)
        return defaults;
    let DEFAULT_ENCODE_TOOLS_OPTIONS = EncodeToolsBase.isNative ? EncodeToolsNative_1.DEFAULT_ENCODE_TOOLS_NATIVE_OPTIONS : EncodeToolsAuto_1.DEFAULT_ENCODE_TOOLS_OPTIONS;
    let rcFile;
    if (process.env.ENCLIRC) {
        rcFile = JSON.parse(process.env.ENCLIRC);
    }
    else {
        rcFile = global.DEFAULT_ENCODE_TOOLS_OPTIONS || {};
    }
    if (!rcFile) {
        let viablePaths = [
            process.env.ENCLIRC_PATH,
            path.join(process.cwd(), '.enclirc'),
            path.join(os.homedir(), '.enclirc')
        ].filter(Boolean);
        for (let file of viablePaths) {
            try {
                if (file && fs_1.existsSync(file)) {
                    rcFile = JSON.parse(fs_1.readFileSync(file, 'utf8'));
                    break;
                }
            }
            catch (err) {
            }
        }
    }
    let origKeys = new Map();
    let keys = Object.keys(DEFAULT_ENCODE_TOOLS_OPTIONS).map((k) => {
        let key = [];
        for (let l of k.split('')) {
            let isUpperCase = l.toUpperCase() === l;
            if (isUpperCase)
                key.push('_');
            key.push(l.toUpperCase());
        }
        let newKey = `ENCLI_${key.join('')}`;
        origKeys.set(newKey, k);
        return newKey;
    });
    for (let envVar in process.env) {
        if (keys.includes(envVar)) {
            rcFile[origKeys.get(envVar)] = process.env[envVar];
        }
    }
    defaults = Object.assign(Object.assign(Object.assign({}, DEFAULT_ENCODE_TOOLS_OPTIONS), { binaryEncoding: EncodeToolsAuto_1.BinaryEncoding.nodeBuffer }), rcFile);
    return defaults;
}
exports.getDefaults = getDefaults;
class EncodeToolsBase extends command_1.Command {
    async getInputAsBuffer(args) {
        let inputStream;
        if (!args.inputBuffer)
            args.inputBuffer = '-';
        if (args.inputBuffer !== '-')
            inputStream = fs_1.createReadStream(args.inputBuffer);
        else
            inputStream = process.stdin;
        return await new Promise((resolve, reject) => {
            let buf = [];
            inputStream.on('data', (data) => {
                buf.push(data);
            });
            inputStream.once('end', (() => {
                resolve(Buffer.concat(buf));
            }));
            inputStream.once('error', ((err) => {
                reject(err);
            }));
        });
    }
    async getOutputAsStream(args) {
        let outputStream;
        if (!args.returnValue)
            args.returnValue = '-';
        if (args.returnValue !== '-')
            outputStream = fs_1.createWriteStream(args.returnValue);
        else
            outputStream = process.stdout;
        return outputStream;
    }
    async getInputOutput(args) {
        const [input, output] = await Promise.all([
            this.getInputAsBuffer(args),
            this.getOutputAsStream(args)
        ]);
        return { input, output };
    }
    static get isNative() {
        return !Object.keys(EncodeToolsAuto_1.EncodeToolsAuto.WithDefaults.availableNativeModules).map(k => EncodeToolsAuto_1.EncodeToolsAuto.WithDefaults.availableNativeModules[k]).includes(false);
    }
    static get EncodeTools() {
        return EncodeToolsAuto_1.EncodeToolsAuto;
    }
}
exports.default = EncodeToolsBase;
EncodeToolsBase.flags = {
    help: command_1.flags.help(),
    args: command_1.flags.string({
        multiple: true,
        char: 'a',
        required: false,
        description: 'Additional args to pass to the encoder'
    })
};
EncodeToolsBase.ioArgs = [
    {
        name: 'inputBuffer',
        required: false,
        description: 'Path to input data, leave blank or use "-" for stdin',
        default: '-'
    },
    {
        name: 'returnValue',
        required: false,
        description: 'Path to use as output, leave blank or use "-" for stdout',
        default: '-'
    }
];
exports.DEFAULT_ENCODE_TOOLS_OPTIONS = EncodeToolsBase.isNative ? EncodeToolsNative_1.DEFAULT_ENCODE_TOOLS_NATIVE_OPTIONS : EncodeToolsAuto_1.DEFAULT_ENCODE_TOOLS_OPTIONS;
