"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const EncodeToolsAuto_1 = require("@znetstar/encode-tools-native/lib/EncodeToolsAuto");
const EncodeToolsBase_1 = require("./EncodeToolsBase");
const encodeBuffer_1 = require("./encodeBuffer");
class Compress extends EncodeToolsBase_1.default {
    encoder(flags) {
        return new (EncodeToolsBase_1.default.EncodeTools)({
            compressionFormat: flags.compressionFormat,
            compressionLevel: flags.compressionLevel,
            binaryEncoding: flags.format
        });
    }
    async run() {
        const { args, flags } = this.parse(Compress);
        const { input, output } = await this.getInputOutput(args);
        const enc = this.encoder(flags);
        const outputBuffer = enc.encodeBuffer(await enc.compress(input, flags.compressionFormat, flags.compressionLevel, ...flags.args || []), flags.format);
        output.end(outputBuffer);
        process.exit(0);
    }
}
exports.default = Compress;
Compress.description = 'Compresses arbitrary data using the provided format and any options, writing the output to a file or stdout';
Compress.example = `echo 'hi' | encli compress -c lzma | xz -d`;
Compress.flags = Object.assign(Object.assign({ help: command_1.flags.help(), compressionFormat: command_1.flags.enum({
        char: 'c',
        required: false,
        default: EncodeToolsBase_1.getDefaults().compressionFormat,
        options: [
            EncodeToolsAuto_1.CompressionFormat.zstd,
            EncodeToolsAuto_1.CompressionFormat.lzma
        ],
        description: 'Format to use'
    }) }, encodeBuffer_1.EncodingFlags), { args: command_1.flags.string({
        multiple: true,
        char: 'a',
        required: false,
        description: 'Additional args to pass to the encoder'
    }), compressionLevel: command_1.flags.integer({
        char: 'l',
        required: false,
        default: EncodeToolsBase_1.getDefaults().compressionLevel,
        description: 'Compression level, passed to underlying algorithm'
    }) });
Compress.args = [
    {
        name: 'inputBuffer',
        required: false,
        description: 'Path to input data, leave blank or use "-" for stdin',
        default: '-'
    },
    {
        name: 'returnValue',
        required: false,
        description: 'Path to use as output, leave blank or use "-" for stdout',
        default: '-'
    }
];
