"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ImageOperationFlags = void 0;
const command_1 = require("@oclif/command");
const EncodeToolsAuto_1 = require("@znetstar/encode-tools-native/lib/EncodeToolsAuto");
const EncodeToolsBase_1 = require("./EncodeToolsBase");
const encodeBuffer_1 = require("./encodeBuffer");
exports.ImageOperationFlags = {
    imageFormat: command_1.flags.enum({
        char: 'i',
        required: false,
        default: EncodeToolsBase_1.getDefaults().imageFormat,
        options: [
            EncodeToolsAuto_1.ImageFormat.jpeg,
            EncodeToolsAuto_1.ImageFormat.png,
            ...( /*EncodeToolsBase.isNative*/true ? [
                EncodeToolsAuto_1.ImageFormat.gif,
                EncodeToolsAuto_1.ImageFormat.tiff,
                EncodeToolsAuto_1.ImageFormat.avif,
                EncodeToolsAuto_1.ImageFormat.webp
            ] : []),
        ],
        description: ' Format to save result as'
    }),
};
class ConvertImage extends EncodeToolsBase_1.default {
    encoder(flags) {
        return new (EncodeToolsBase_1.default.EncodeTools)({
            imageFormat: flags.imageFormat,
            binaryEncoding: flags.format
        });
    }
    async run() {
        const { args, flags } = this.parse(ConvertImage);
        const { input, output } = await this.getInputOutput(args);
        const enc = this.encoder(flags);
        const outputBuffer = enc.encodeBuffer(await enc.convertImage(input, flags.imageFormat), flags.format);
        output.end(outputBuffer);
        process.exit(0);
    }
}
exports.default = ConvertImage;
ConvertImage.description = 'Saves an image in the provided format, performing no operations on the image writing the result to to a file or stdout';
ConvertImage.example = `curl -sL 'https://zb.gy/potd/wiki' | encli convertImage png - /tmp/photo.png; open /tmp/photo.png`;
ConvertImage.flags = Object.assign(Object.assign(Object.assign({ help: command_1.flags.help() }, exports.ImageOperationFlags), encodeBuffer_1.EncodingFlags), { args: command_1.flags.string({
        multiple: true,
        char: 'a',
        required: false,
        description: 'Additional args to pass to the encoder'
    }) });
ConvertImage.args = [
    {
        name: 'inputBuffer',
        required: false,
        description: 'Path to input data, leave blank or use "-" for stdin',
        default: '-'
    },
    {
        name: 'returnValue',
        required: false,
        description: 'Path to use as output, leave blank or use "-" for stdout',
        default: '-'
    }
];
