"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DeserializingFlags = exports.SerializingFlags = exports.ReserializingFlags = void 0;
const command_1 = require("@oclif/command");
const EncodeToolsAuto_1 = require("@znetstar/encode-tools-native/lib/EncodeToolsAuto");
const EncodeToolsBase_1 = require("./EncodeToolsBase");
const encodeBuffer_1 = require("./encodeBuffer");
exports.ReserializingFlags = {
    inputSerializationFormat: command_1.flags.enum({
        char: 'i',
        required: false,
        default: EncodeToolsBase_1.getDefaults().serializationFormat,
        options: [
            EncodeToolsAuto_1.SerializationFormat.json,
            EncodeToolsAuto_1.SerializationFormat.cbor,
            EncodeToolsAuto_1.SerializationFormat.msgpack,
            EncodeToolsAuto_1.SerializationFormat.bson
        ],
        description: 'Format to deserialize input as'
    }),
    outputSerializationFormat: command_1.flags.enum({
        char: 'o',
        required: false,
        default: EncodeToolsBase_1.getDefaults().serializationFormat,
        options: [
            EncodeToolsAuto_1.SerializationFormat.json,
            EncodeToolsAuto_1.SerializationFormat.cbor,
            EncodeToolsAuto_1.SerializationFormat.msgpack,
            EncodeToolsAuto_1.SerializationFormat.bson
        ],
        description: 'Format to serialize output as'
    })
};
exports.SerializingFlags = {
    serializationFormat: command_1.flags.enum({
        char: 's',
        required: false,
        default: EncodeToolsBase_1.getDefaults().serializationFormat,
        options: [
            EncodeToolsAuto_1.SerializationFormat.json,
            EncodeToolsAuto_1.SerializationFormat.cbor,
            EncodeToolsAuto_1.SerializationFormat.msgpack,
            EncodeToolsAuto_1.SerializationFormat.bson
        ],
        description: 'Format to serialize output as'
    })
};
exports.DeserializingFlags = {
    serializationFormat: command_1.flags.enum({
        char: 's',
        required: false,
        default: EncodeToolsBase_1.getDefaults().serializationFormat,
        options: [
            EncodeToolsAuto_1.SerializationFormat.json,
            EncodeToolsAuto_1.SerializationFormat.cbor,
            EncodeToolsAuto_1.SerializationFormat.msgpack,
            EncodeToolsAuto_1.SerializationFormat.bson
        ],
        description: 'Format to deserialize input from'
    })
};
class ConvertObject extends EncodeToolsBase_1.default {
    encoder(flags) {
        return new (EncodeToolsBase_1.default.EncodeTools)({
            serializationFormat: flags.inputSerializationFormat
        });
    }
    async run() {
        const { args, flags } = this.parse(ConvertObject);
        const { input, output } = await this.getInputOutput(args);
        const inEnc = new (EncodeToolsBase_1.default.EncodeTools)({ serializationFormat: flags.inputSerializationFormat, binaryEncoding: flags.format });
        const outEnc = new (EncodeToolsBase_1.default.EncodeTools)({ serializationFormat: flags.outputSerializationFormat, binaryEncoding: flags.format });
        const outputBuffer = outEnc.serializeObject(inEnc.deserializeObject(input, flags.inputSerializationFormat));
        output.end(outputBuffer);
        process.exit(0);
    }
}
exports.default = ConvertObject;
ConvertObject.description = 'Re-encodes data in one serialization format in a different serialization format. The binary encoding must stay the same';
ConvertObject.example = `echo '{"my": "json"}' | encli convertObject -i json -o msgpack | encli encodeBuffer -f base64`;
ConvertObject.flags = Object.assign(Object.assign(Object.assign({ help: command_1.flags.help() }, exports.ReserializingFlags), encodeBuffer_1.EncodingFlags), { args: command_1.flags.string({
        multiple: true,
        char: 'a',
        required: false,
        description: 'Additional args to pass to the encoder'
    }) });
ConvertObject.args = [
    {
        name: 'inputBuffer',
        required: false,
        description: 'Path to input data, leave blank or use "-" for stdin',
        default: '-'
    },
    {
        name: 'returnValue',
        required: false,
        description: 'Path to use as output, leave blank or use "-" for stdout',
        default: '-'
    }
];
