"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const EncodeToolsBase_1 = require("./EncodeToolsBase");
const encodeBuffer_1 = require("./encodeBuffer");
const convertImage_1 = require("./convertImage");
class CropImage extends EncodeToolsBase_1.default {
    encoder(flags) {
        return new (EncodeToolsBase_1.default.EncodeTools)({
            imageFormat: flags.imageFormat,
            binaryEncoding: flags.format
        });
    }
    async run() {
        const { args, flags } = this.parse(CropImage);
        const { input, output } = await this.getInputOutput(args);
        const enc = this.encoder(flags);
        const outputBuffer = enc.encodeBuffer(await enc.cropImage(input, { height: flags.height, width: flags.width, top: flags.top, left: flags.left }, flags.imageFormat), flags.format);
        output.end(outputBuffer);
        process.exit(0);
    }
}
exports.default = CropImage;
CropImage.description = 'Crops an image and writes the result in the provided format to to a file or stdout';
CropImage.example = `curl -sL 'https://zb.gy/potd/wiki' | encli cropImage -w 300 -h 300 -x 10 -y 10 -i png - /tmp/photo.png; open /tmp/photo.png`;
CropImage.flags = Object.assign(Object.assign(Object.assign({ help: command_1.flags.help() }, convertImage_1.ImageOperationFlags), encodeBuffer_1.EncodingFlags), { args: command_1.flags.string({
        multiple: true,
        char: 'a',
        required: false,
        description: 'Additional args to pass to the encoder'
    }), height: command_1.flags.integer({
        char: 'h',
        required: true,
        description: 'Height to crop to'
    }), width: command_1.flags.integer({
        char: 'w',
        required: true,
        description: 'Width to crop to.'
    }), top: command_1.flags.integer({
        char: 'x',
        required: true,
        description: 'Where to begin the crop on the x-axis'
    }), left: command_1.flags.integer({
        char: 'y',
        required: true,
        description: 'Where to begin the crop on the y-axis'
    }) });
CropImage.args = [
    {
        name: 'inputBuffer',
        required: false,
        description: 'Path to input data, leave blank or use "-" for stdin',
        default: '-'
    },
    {
        name: 'returnValue',
        required: false,
        description: 'Path to use as output, leave blank or use "-" for stdout',
        default: '-'
    }
];
