"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DecodingFlags = void 0;
const command_1 = require("@oclif/command");
const EncodeToolsAuto_1 = require("@znetstar/encode-tools-native/lib/EncodeToolsAuto");
const EncodeToolsBase_1 = require("./EncodeToolsBase");
exports.DecodingFlags = {
    format: command_1.flags.enum({
        char: 'f',
        required: false,
        default: EncodeToolsBase_1.getDefaults().binaryEncoding,
        options: [
            EncodeToolsAuto_1.BinaryEncoding.base64url,
            EncodeToolsAuto_1.BinaryEncoding.hashids,
            EncodeToolsAuto_1.BinaryEncoding.base32,
            EncodeToolsAuto_1.BinaryEncoding.base64,
            EncodeToolsAuto_1.BinaryEncoding.arrayBuffer,
            EncodeToolsAuto_1.BinaryEncoding.nodeBuffer,
            EncodeToolsAuto_1.BinaryEncoding.hex,
            EncodeToolsAuto_1.BinaryEncoding.ascii85
        ],
        description: 'Format to decode input from'
    })
};
class DecodeBuffer extends EncodeToolsBase_1.default {
    encoder(flags) {
        return new (EncodeToolsBase_1.default.EncodeTools)({
            binaryEncoding: flags.format
        });
    }
    async run() {
        const { args, flags } = this.parse(DecodeBuffer);
        const { input, output } = await this.getInputOutput(args);
        const enc = this.encoder(flags);
        const outputBuffer = enc.decodeBuffer(input, flags.format, ...flags.args || []);
        output.end(outputBuffer);
        process.exit(0);
    }
}
exports.default = DecodeBuffer;
DecodeBuffer.description = 'Decodes binary data from the provided format writing the output to a file or stdout';
DecodeBuffer.example = `echo 'bXkgaHVnZSBmaWxlCg==' | encli decodeBuffer -f base64`;
DecodeBuffer.flags = Object.assign(Object.assign({ help: command_1.flags.help() }, exports.DecodingFlags), { args: command_1.flags.string({
        multiple: true,
        char: 'a',
        required: false,
        description: 'Additional args to pass to the encoder'
    }) });
DecodeBuffer.args = [
    {
        name: 'input',
        required: false,
        description: 'Path to input data, leave blank or use "-" for stdin',
        default: '-'
    },
    {
        name: 'returnValue',
        required: false,
        description: 'Path to use as output, leave blank or use "-" for stdout',
        default: '-'
    }
];
