"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const EncodeToolsAuto_1 = require("@znetstar/encode-tools-native/lib/EncodeToolsAuto");
const EncodeToolsBase_1 = require("./EncodeToolsBase");
const encodeBuffer_1 = require("./encodeBuffer");
class Decompress extends EncodeToolsBase_1.default {
    encoder(flags) {
        return new (EncodeToolsBase_1.default.EncodeTools)({
            compressionFormat: flags.compressionFormat,
            binaryEncoding: flags.format
        });
    }
    async run() {
        const { args, flags } = this.parse(Decompress);
        const { input, output } = await this.getInputOutput(args);
        const enc = this.encoder(flags);
        const outputBuffer = enc.encodeBuffer(await enc.decompress(input, flags.compressionFormat, ...flags.args || []), flags.format);
        output.end(outputBuffer);
        process.exit(0);
    }
}
exports.default = Decompress;
Decompress.description = 'Decompresses arbitrary data using the provided format and any options, writing the output to a file or stdout';
Decompress.example = `echo 'hi' | xz | encli decompress -c lzma`;
Decompress.flags = Object.assign(Object.assign({ help: command_1.flags.help(), compressionFormat: command_1.flags.enum({
        char: 'c',
        required: false,
        default: EncodeToolsBase_1.getDefaults().compressionFormat,
        options: [
            EncodeToolsAuto_1.CompressionFormat.zstd,
            EncodeToolsAuto_1.CompressionFormat.lzma
        ],
        description: 'Format to use'
    }) }, encodeBuffer_1.EncodingFlags), { args: command_1.flags.string({
        multiple: true,
        char: 'a',
        required: false,
        description: 'Additional args to pass to the encoder'
    }) });
Decompress.args = [
    {
        name: 'inputBuffer',
        required: false,
        description: 'Path to input data, leave blank or use "-" for stdin',
        default: '-'
    },
    {
        name: 'returnValue',
        required: false,
        description: 'Path to use as output, leave blank or use "-" for stdout',
        default: '-'
    }
];
