"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const EncodeToolsBase_1 = require("./EncodeToolsBase");
const encodeBuffer_1 = require("./encodeBuffer");
const convertObject_1 = require("./convertObject");
const hash_1 = require("./hash");
class HashObject extends EncodeToolsBase_1.default {
    encoder(flags) {
        return new (EncodeToolsBase_1.default.EncodeTools)({
            binaryEncoding: flags.format,
            hashAlgorithm: flags.algorithm
        });
    }
    async run() {
        const { args, flags } = this.parse(HashObject);
        const { input, output } = await this.getInputOutput(args);
        const enc = this.encoder(flags);
        const outputBuffer = enc.encodeBuffer(await enc.hashObject(enc.deserializeObject(input, flags.serializationFormat), flags.algorithm, ...flags.args || []), flags.format);
        output.end(outputBuffer);
        process.exit(0);
    }
}
exports.default = HashObject;
HashObject.description = 'Hashes an object using the provided algorithm. The object will be deserialized first using "deserializeObject". writing the output to a file or stdout';
HashObject.example = "echo '{ \"foo\": \"bar\" }' | encli hash -s json -a xxhash3 -f base64";
HashObject.flags = Object.assign(Object.assign(Object.assign(Object.assign({ help: command_1.flags.help() }, hash_1.HashingFlags), convertObject_1.SerializingFlags), encodeBuffer_1.EncodingFlags), { args: command_1.flags.string({
        multiple: true,
        char: 'a',
        required: false,
        description: 'Additional args to pass to the encoder'
    }) });
HashObject.args = [
    {
        name: 'inputBuffer',
        required: false,
        description: 'Path to input data, leave blank or use "-" for stdin',
        default: '-'
    },
    {
        name: 'returnValue',
        required: false,
        description: 'Path to use as output, leave blank or use "-" for stdout',
        default: '-'
    }
];
