"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const EncodeToolsBase_1 = require("./EncodeToolsBase");
const encodeBuffer_1 = require("./encodeBuffer");
const convertImage_1 = require("./convertImage");
class ResizeImage extends EncodeToolsBase_1.default {
    encoder(flags) {
        return new (EncodeToolsBase_1.default.EncodeTools)({
            imageFormat: flags.imageFormat,
            binaryEncoding: flags.format
        });
    }
    async run() {
        const { args, flags } = this.parse(ResizeImage);
        const { input, output } = await this.getInputOutput(args);
        const enc = this.encoder(flags);
        const outputBuffer = enc.encodeBuffer(await enc.resizeImage(input, { height: flags.height, width: flags.width }, flags.imageFormat), flags.format);
        output.end(outputBuffer);
        process.exit(0);
    }
}
exports.default = ResizeImage;
ResizeImage.description = 'Resizes an image and writes the result in the provided format to to a file or stdout';
ResizeImage.example = `curl -sL 'https://zb.gy/potd/wiki' | encli resizeImage -w 200 -i png - /tmp/photo.png; open /tmp/photo.png`;
ResizeImage.flags = Object.assign(Object.assign(Object.assign({ help: command_1.flags.help() }, convertImage_1.ImageOperationFlags), encodeBuffer_1.EncodingFlags), { args: command_1.flags.string({
        multiple: true,
        char: 'a',
        required: false,
        description: 'Additional args to pass to the encoder'
    }), height: command_1.flags.integer({
        char: 'h',
        required: false,
        description: 'Height to resize to. Must provide, height, width or both'
    }), width: command_1.flags.integer({
        char: 'w',
        required: false,
        description: 'Width to resize to. Must provide, height, width or both'
    }) });
ResizeImage.args = [
    {
        name: 'inputBuffer',
        required: false,
        description: 'Path to input data, leave blank or use "-" for stdin',
        default: '-'
    },
    {
        name: 'returnValue',
        required: false,
        description: 'Path to use as output, leave blank or use "-" for stdout',
        default: '-'
    }
];
