"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const EncodeToolsAuto_1 = require("@znetstar/encode-tools-native/lib/EncodeToolsAuto");
const EncodeToolsBase_1 = require("./EncodeToolsBase");
const encodeBuffer_1 = require("./encodeBuffer");
class UniqueId extends EncodeToolsBase_1.default {
    encoder(flags) {
        return new (EncodeToolsBase_1.default.EncodeTools)({
            binaryEncoding: flags.format,
            uniqueIdFormat: flags.idFormat
        });
    }
    async run() {
        const { args, flags } = this.parse(UniqueId);
        const output = await this.getOutputAsStream(args);
        const enc = this.encoder(flags);
        let value = enc.uniqueId(flags.idFormat, ...flags.args || []);
        if (typeof (value) === 'number') {
            value = Buffer.from(value.toString(16), 'hex');
        }
        const outputBuffer = enc.encodeBuffer(value, flags.format);
        output.end(outputBuffer);
        process.exit(0);
    }
}
exports.default = UniqueId;
UniqueId.description = 'Generates a unique ID using one of the available algorithms, writing the output to a file or stdout';
UniqueId.example = `encli uniqueId -i uuidv4 -f base64`;
UniqueId.flags = Object.assign(Object.assign({ help: command_1.flags.help(), idFormat: command_1.flags.enum({
        char: 'i',
        required: false,
        default: EncodeToolsBase_1.getDefaults().uniqueIdFormat,
        options: [
            EncodeToolsAuto_1.IDFormat.timestamp,
            EncodeToolsAuto_1.IDFormat.objectId,
            EncodeToolsAuto_1.IDFormat.uuidv4String,
            EncodeToolsAuto_1.IDFormat.uuidv1String,
            EncodeToolsAuto_1.IDFormat.nanoid,
            EncodeToolsAuto_1.IDFormat.uuidv4,
            EncodeToolsAuto_1.IDFormat.uuidv1
        ],
        description: 'Algorithm to use to generate the unique id'
    }) }, encodeBuffer_1.EncodingFlags), { args: command_1.flags.string({
        multiple: true,
        char: 'a',
        required: false,
        description: 'Extra args to pass to the ID generation function'
    }) });
UniqueId.args = [
    {
        name: 'returnValue',
        required: false,
        description: 'Path to use as output, leave blank or use "-" for stdout',
        default: '-'
    }
];
